@@ -127,18 +127,22 @@ def install():
         restart_nginx()
 
         # Install Docker if not available
+
+        docker_install_script_path = os.path.join(absolute_package_path, "scripts", "docker-install.sh")
+        docker_compose_install_script_path = os.path.join(absolute_package_path, "scripts", "docker-compose-install.sh")
+
         if is_installed("docker"):
             echo("Docker is already installed.")
         else:
             echo("Installing Docker")
-            subprocess.call(["sudo", "sh", "scripts/docker-install.sh"])
+            subprocess.call(["sudo", "sh", docker_install_script_path])
 
         # Install Docker Compose if not available
         if is_installed("docker compose", "version"):
             echo("Docker Compose is already installed.")
         else:
             echo("Installing Docker Compose")
-            subprocess.call(["sudo", "sh", "docker-compose-install.sh"])
+            subprocess.call(["sudo", "sh", docker_compose_install_script_path])
 
         if is_installed("certbot", "--version"):
             echo("Certbot is already installed.")
